﻿using System;
using System.IO;

namespace TryingUsing
{
    internal class Program
    {
        public static String ReadFirstLine(String filename)
        {
            StreamReader reader = new StreamReader(filename);
            String line = reader.ReadLine();
            reader.Close();
            // if you get an exception reading the file, the close() line is never executed
            return line;
        }

        public static String ReadFirstLineBetter(String filename)
        {
            StreamReader reader = null;
            try
            {
                reader = new StreamReader(filename);
                String line = reader.ReadLine();
                return line;
            }
            finally
            {
                if (reader != null)
                {
                    reader.Close();
                }
            }
        }

        public static String ReadFirstLineBest(String filename)
        {
            using (StreamReader reader = new StreamReader(filename))
            {
                String line = reader.ReadLine();
                return line;
                // automatic closing
            }
        }

        private static void Main()
        {
            const string filename = "c:/temp/file.txt";
            try
            {
                Console.WriteLine(ReadFirstLine(filename));
                Console.WriteLine(ReadFirstLineBetter(filename));

                Console.WriteLine(ReadFirstLineBest(filename));
            }
            catch (FileNotFoundException ex)
            {
                Console.WriteLine("here" + ex.Message);
                throw new MyException(ex.Message, ex);
            }
            catch (IOException ex)
            {
                Console.WriteLine(ex.Message);
            }
        }
    }
}